@@ -71,7 +71,7 @@ from progressbar.widgets import *
 __author__ = 'Rick van Hattem'
 __author_email__ = 'Rick.van.Hattem@Fawo.nl'
 __date__ = str(date.today())
-__version__ = '2.6.8'
+__version__ = '2.6.9'
 
 
 class UnknownLength:
@@ -128,16 +128,15 @@ class ProgressBar(object):
 
     _DEFAULT_MAXVAL = 100
     _DEFAULT_TERMSIZE = 80
-    _DEFAULT_WIDGETS = [Percentage(), ' ', Bar()]
 
     def __init__(self, maxval=None, widgets=None, term_width=None, poll=0.1,
                  left_justify=True, fd=sys.stderr, redirect_stderr=False,
                  redirect_stdout=False):
         '''Initializes a progress bar with sane defaults'''
 
-        # Don't share a reference with any other progress bars
         if widgets is None:
-            widgets = list(self._DEFAULT_WIDGETS)
+            # Don't share widgets with any other progress bars
+            widgets = self.default_widgets()
 
         self.maxval = maxval
         self.widgets = widgets
@@ -169,6 +168,12 @@ class ProgressBar(object):
         self.start_time = None
         self.update_interval = 1
 
+    def default_widgets(self):
+        return [
+            Percentage(), ' (', SimpleProgress(), ')', ' ', Bar(), ' ',
+            Timer(), ' ', AdaptiveETA(),
+        ]
+
     def __call__(self, iterable, maxval=None):
         'Use a ProgressBar to iterate through an iterable'
         if maxval is None:
